@@ -23,6 +23,19 @@ XPtrImage magick_image_fx( XPtrImage input, std::string expression, Rcpp::Charac
   return output;
 }
 
+// [[Rcpp::export]]
+XPtrImage magick_image_fx_sequence( XPtrImage input, const std::string expr){
+#if MagickLibVersion >= 0x688
+  Frame x;
+  Magick::fxImages(&x, input->begin(), input->end(), expr);
+  XPtrImage output = create(1);
+  output->push_back(x);
+  return output;
+#else
+  throw std::runtime_error("ImageMagick too old to support fx_sequence (requires >= 6.8.8)");
+#endif
+}
+
 #if MagickLibVersion >= 0x689
 
 Magick::KernelInfoType Kernel(const char * str){
@@ -42,7 +55,7 @@ Magick::MorphologyMethod Method(const char * str){
 }
 
 // [[Rcpp::export]]
-XPtrImage magick_image_morphology( XPtrImage input, std::string method, std::string kernel, size_t iter,
+XPtrImage magick_image_morphology( XPtrImage input, std::string method, std::string kernel, ssize_t iter,
                                    Rcpp::CharacterVector opt_names, Rcpp::CharacterVector opt_values){
   XPtrImage output = copy(input);
   for (int i = 0; i < opt_values.length(); i++){
@@ -55,7 +68,7 @@ XPtrImage magick_image_morphology( XPtrImage input, std::string method, std::str
 }
 
 // [[Rcpp::export]]
-XPtrImage magick_image_convolve_kernel( XPtrImage input, std::string kernel, size_t iter,
+XPtrImage magick_image_convolve_kernel( XPtrImage input, std::string kernel, ssize_t iter,
                                  Rcpp::CharacterVector scaling, Rcpp::CharacterVector bias){
   XPtrImage output = copy(input);
   if(scaling.length()){
@@ -90,12 +103,12 @@ XPtrImage magick_image_convolve_matrix( XPtrImage input, Rcpp::NumericMatrix mat
 }
 
 #else
-XPtrImage magick_image_morphology( XPtrImage input, std::string method, std::string kernel, size_t iter,
+XPtrImage magick_image_morphology( XPtrImage input, std::string method, std::string kernel, ssize_t iter,
                                    Rcpp::CharacterVector opt_names, Rcpp::CharacterVector opt_values){
   throw std::runtime_error("ImageMagick too old. Morphology requires at least version  6.8.8");
 }
 
-XPtrImage magick_image_convolve_kernel( XPtrImage input, std::string kernel, size_t iter,
+XPtrImage magick_image_convolve_kernel( XPtrImage input, std::string kernel, ssize_t iter,
                                         Rcpp::CharacterVector scaling, Rcpp::CharacterVector bias){
   throw std::runtime_error("ImageMagick too old. Convolve requires at least version  6.8.8");
 }
